@@ -7,8 +7,6 @@
 import subprocess
 import sys
 import os
-import time
-from progress.bar import IncrementalBar
 
 
 def install(package: str, check=True):
@@ -26,11 +24,8 @@ def pip_upgrade():
 
 def required():
     require = ["requests", "opencv-python", "progress"]
-    bar = IncrementalBar('Countdown', max=len(require))
     print("Установка необходимых библиотек")
     for i in range(len(require)):
         install(require[i], check=False)
-        bar.next()
-        time.sleep(1)
-    bar.finish()
+        print(f"{i + 1}/{len(require)}")
     print("Установка завершена")
